Enum Affinity
pub enum Affinity {
Downstream = 0,
Upstream = 1,
}Expand description
Determines how a cursor attaches to a cluster.
Variants
Downstream = 0
Cursor is attached to the character that is logically following in the text stream.
Upstream = 1
Cursor is attached to the character that is logically preceding in the text stream.
Implementations