Enum Alignment
#[repr(u8)]pub enum Alignment {
Start = 0,
End = 1,
Left = 2,
Center = 3,
Right = 4,
Justify = 5,
}Expand description
Alignment of a layout.
Variants
Start = 0
This is Alignment::Left for LTR text and Alignment::Right for RTL text.
End = 1
This is Alignment::Right for LTR text and Alignment::Left for RTL text.
Left = 2
Align content to the left edge.
For alignment that should be aware of text direction, use Alignment::Start or
Alignment::End instead.
Center = 3
Align each line centered within the container.
Right = 4
Align content to the right edge.
For alignment that should be aware of text direction, use Alignment::Start or
Alignment::End instead.
Justify = 5
Justify each line by spacing out content, except for the last line.