Enum OverflowWrap
#[repr(u8)]pub enum OverflowWrap {
Normal = 0,
Anywhere = 1,
BreakWord = 2,
}Expand description
Control over “emergency” line-breaking.
See https://drafts.csswg.org/css-text/#overflow-wrap-property for more information.
Variants
Normal = 0
Even with extremely long words, lines can only break at places specified in
WordBreakStrength.
Anywhere = 1
Words may be broken at an arbitrary point if there are no other places in the line to break them.
BreakWord = 2
Like OverflowWrap::Anywhere, except arbitrary wrapping opportunities are not considered
when calculating the minimum content width (see [crate::Layout::calculate_content_widths]).