Enum WordBreakStrength
#[repr(u8)]pub enum WordBreakStrength {
Normal = 0,
BreakAll = 1,
KeepAll = 2,
}Expand description
Word breaking strength (corresponds to https://drafts.csswg.org/css-text/#word-break-property).
Variants
Normal = 0
Words can be broken according to their normal Unicode rules.
BreakAll = 1
Breaking treats numeric, alphabetic, and Southeast Asian classes as Ideographic. Note that this does not affect breaking punctuation.
KeepAll = 2
Breaking between typographic letter units or the NU, AL, AI, or ID classes is prohibited.