TextSelection

Struct TextSelection 

pub struct TextSelection { /* private fields */ }
A TextLayout-owned selection value.

This wraps Parley’s selection type for APIs that depend on TextLayout’s selection-geometry invariants and cache lifecycle.

Methods from Deref<Target = Selection>

pub fn is_collapsed(&self) -> bool

Returns true if the anchor and focus of the selection are the same.

This means that the selection represents a single position rather than a range.

pub fn anchor(&self) -> Cursor

Returns the anchor of the selection.

In a non-collapsed selection, this indicates where the selection was initiated.

pub fn focus(&self) -> Cursor

Returns the focus of the selection.

In a non-collapsed selection, this indicates the current position.

pub fn collapse(&self) -> Selection

Returns a new collapsed selection at the position of the current focus.

pub fn refresh<B>(&self, layout: &Layout<B>) -> Selection
where B: Brush,

Returns a new selection that is guaranteed to be within the bounds of the given layout.

pub fn text_range(&self) -> Range<usize>

Returns the underlying text range of the selection.

pub fn next_visual<B>(&self, layout: &Layout<B>, extend: bool) -> Selection
where B: Brush,

Returns a new selection with the focus at the next cluster in visual order.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn previous_visual<B>(&self, layout: &Layout<B>, extend: bool) -> Selection
where B: Brush,

Returns a new selection with the focus at the previous cluster in visual order.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn next_visual_word<B>(&self, layout: &Layout<B>, extend: bool) -> Selection
where B: Brush,

Returns a new selection with the focus moved to the next word in visual order.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn previous_visual_word<B>( &self, layout: &Layout<B>, extend: bool, ) -> Selection
where B: Brush,

Returns a new selection with the focus moved to the previous word in visual order.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn next_line<B>(&self, layout: &Layout<B>, extend: bool) -> Selection
where B: Brush,

Returns a new selection with the focus moved to the next line. The current horizontal position will be maintained.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn previous_line<B>(&self, layout: &Layout<B>, extend: bool) -> Selection
where B: Brush,

Returns a new selection with the focus moved to the previous line. The current horizontal position will be maintained.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn move_lines<B>( &self, layout: &Layout<B>, delta: isize, extend: bool, ) -> Selection
where B: Brush,

Returns a new selection with the focus moved the specified number of lines.

The sign of the delta parameter determines the direction to move with negative values moving toward previous lines and positive ones moving toward next lines.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn line_start<B>(&self, layout: &Layout<B>, extend: bool) -> Selection
where B: Brush,

Returns a new selection with the focus moved to the start of the current line.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn hard_line_start<B>(&self, layout: &Layout<B>, extend: bool) -> Selection
where B: Brush,

Returns a new selection with the focus moved to just after the previous hard line break.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn line_end<B>(&self, layout: &Layout<B>, extend: bool) -> Selection
where B: Brush,

Returns a new selection with the focus moved to the end of the current line.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn hard_line_end<B>(&self, layout: &Layout<B>, extend: bool) -> Selection
where B: Brush,

Returns a new selection with the focus moved to just before the next hard line break.

If extend is true then the current anchor will be retained, otherwise the new selection will be collapsed.

pub fn extend_to_point<B>( &self, layout: &Layout<B>, x: f32, y: f32, ) -> Selection
where B: Brush,

Returns a new selection with the focus extended to the given point.

If the initial selection was created from a word or line, then the new selection will be extended at the same granularity.

pub fn shift_click_extension<B>( &self, layout: &Layout<B>, x: f32, y: f32, ) -> Selection
where B: Brush,

Returns a new selection with the focus extended to the given point.

pub fn extend(&self, focus: Cursor) -> Selection

Returns a new selection with the current anchor and the focus set to the given value.

pub fn geometry<B>(&self, layout: &Layout<B>) -> Vec<(BoundingBox, usize)>
where B: Brush,

Returns a vector containing the rectangles which represent the visual geometry of this selection for the given layout, and the indices of the lines to which they belong.

This is a convenience method built on geometry_with.

pub fn geometry_with<B>( &self, layout: &Layout<B>, f: impl FnMut(BoundingBox, usize), )
where B: Brush,

Invokes f with the sequence of rectangles which represent the visual geometry of this selection for the given layout, and the indices of the lines to which they belong.

This avoids allocation if the intent is to render the rectangles immediately.