Struct Cursor
pub struct Cursor { /* private fields */ }Expand description
Defines a position with a text layout.
Implementations
impl Cursor
impl Cursor
pub fn from_byte_index<B>(
layout: &Layout<B>,
index: usize,
affinity: Affinity,
) -> Cursorwhere
B: Brush,
pub fn from_byte_index<B>(
layout: &Layout<B>,
index: usize,
affinity: Affinity,
) -> Cursorwhere
B: Brush,
Creates a new cursor from the given byte index and affinity.
pub fn from_point<B>(layout: &Layout<B>, x: f32, y: f32) -> Cursorwhere
B: Brush,
pub fn from_point<B>(layout: &Layout<B>, x: f32, y: f32) -> Cursorwhere
B: Brush,
Creates a new cursor from the given coordinates.
pub fn affinity(&self) -> Affinity
pub fn affinity(&self) -> Affinity
Returns the affinity of the cursor.
This defines the direction from which the cursor entered its current position and affects the visual location of the rendered cursor.
pub fn refresh<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
pub fn refresh<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
Returns a new cursor that is guaranteed to be within the bounds of the given layout.
pub fn previous_visual<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
pub fn previous_visual<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
Returns a new cursor that is positioned at the previous cluster boundary in visual order.
pub fn next_visual<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
pub fn next_visual<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
Returns a new cursor that is positioned at the next cluster boundary in visual order.
pub fn next_visual_word<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
pub fn next_visual_word<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
Returns a new cursor that is positioned at the next word boundary in visual order.
pub fn previous_visual_word<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
pub fn previous_visual_word<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
Returns a new cursor that is positioned at the previous word boundary in visual order.
pub fn next_logical_word<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
pub fn next_logical_word<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
Returns a new cursor that is positioned at the next word boundary in logical order.
pub fn previous_logical_word<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
pub fn previous_logical_word<B>(&self, layout: &Layout<B>) -> Cursorwhere
B: Brush,
Returns a new cursor that is positioned at the previous word boundary in logical order.
pub fn geometry<B>(&self, layout: &Layout<B>, width: f32) -> BoundingBoxwhere
B: Brush,
pub fn geometry<B>(&self, layout: &Layout<B>, width: f32) -> BoundingBoxwhere
B: Brush,
Returns a rectangle that represents the visual geometry of the cursor in layout space.
The width parameter defines the width of the resulting rectangle.
pub fn logical_clusters<'a, B>(
&self,
layout: &'a Layout<B>,
) -> [Option<Cluster<'a, B>>; 2]where
B: Brush,
pub fn logical_clusters<'a, B>(
&self,
layout: &'a Layout<B>,
) -> [Option<Cluster<'a, B>>; 2]where
B: Brush,
Returns the pair of clusters that logically bound the cursor position.
The order in the array is upstream followed by downstream.
pub fn visual_clusters<'a, B>(
&self,
layout: &'a Layout<B>,
) -> [Option<Cluster<'a, B>>; 2]where
B: Brush,
pub fn visual_clusters<'a, B>(
&self,
layout: &'a Layout<B>,
) -> [Option<Cluster<'a, B>>; 2]where
B: Brush,
Returns the pair of clusters that visually bound the cursor position.
The order in the array is left followed by right.